summaryrefslogtreecommitdiffstats
path: root/scripts/zfs-tests.sh
diff options
context:
space:
mode:
authorнаб <[email protected]>2022-04-09 04:09:55 +0200
committerBrian Behlendorf <[email protected]>2022-05-10 10:18:38 -0700
commit5cdca5b1da7884c54260db473f892354bc79951b (patch)
tree6bdce13ac507fd450359dde2b3fa10405a480c54 /scripts/zfs-tests.sh
parent3ff81c460114e0b3f69a9993d4777ec2c590fb16 (diff)
autoconf: use include directives instead of recursing down cmd
No installation diff, dist lost -zfs-2.1.99/cmd/fsck_zfs/fsck.zfs which was distributed erroneously, since it's generated Also clean gitrev on clean Also add -e 'any possible bashisms' to default checkbashisms flags, and fully parallelise it and shellcheck, and it works out-of-tree, too Also align the Release in the dist META file correctly Reviewed-by: Brian Behlendorf <[email protected]> Signed-off-by: Ahelenia Ziemiańska <[email protected]> Closes #13316
Diffstat (limited to 'scripts/zfs-tests.sh')
-rwxr-xr-xscripts/zfs-tests.sh10
1 files changed, 3 insertions, 7 deletions
diff --git a/scripts/zfs-tests.sh b/scripts/zfs-tests.sh
index df69325a1..cad65d048 100755
--- a/scripts/zfs-tests.sh
+++ b/scripts/zfs-tests.sh
@@ -248,7 +248,7 @@ constrain_path() {
SYSTEM_DIRS="$SYSTEM_DIRS /usr/bin /usr/sbin /bin /sbin $LIBEXEC_DIR"
if [ "$INTREE" = "yes" ]; then
# Constrained path set to ./zfs/bin/
STF_PATH="$BIN_DIR"
STF_PATH_REMOVE="no"
STF_MISSING_BIN=""
@@ -258,14 +258,10 @@ constrain_path() {
fi
# Special case links for standard zfs utilities
- DIRS="$(find "$CMD_DIR" -type d \( ! -name .deps -a \
- ! -name .libs \) -print | tr '\n' ' ')"
- create_links "$DIRS" "$ZFS_FILES"
+ create_links "$CMD_DIR" "$ZFS_FILES"
# Special case links for zfs test suite utilities
- DIRS="$(find "$STF_SUITE" -type d \( ! -name .deps -a \
- ! -name .libs \) -print | tr '\n' ' ')"
- create_links "$DIRS" "$ZFSTEST_FILES"
+ create_links "$CMD_DIR/tests/zfs-tests/cmd" "$ZFSTEST_FILES"
else
# Constrained path set to /var/tmp/constrained_path.*
SYSTEMDIR=${SYSTEMDIR:-/var/tmp/constrained_path.XXXXXX}
@@ -248,7 +248,7 @@ constrain_path() {
SYSTEM_DIRS="$SYSTEM_DIRS /usr/bin /usr/sbin /bin /sbin $LIBEXEC_DIR"
if [ "$INTREE" = "yes" ]; then
- # Constrained path set to ./zfs/bin/
+ # Constrained path set to $(top_builddir)/tests/zfs-tests/bin
STF_PATH="$BIN_DIR"
STF_PATH_REMOVE="no"